@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -39,17 +39,13 @@ C<Future::AsyncAwait> - deferred subroutine syntax for futures
 This module provides syntax for deferring and resuming subroutines while
 waiting for L<Future>s to complete.
 
-B<WARNING>: The actual semantics in this module are not yet implemented. This
-is released purely to demonstrate the syntax parts of its operation, to
-reserve the name on CPAN, and to provide something that actually exists in
-order to look at it. Don't expect to be able to use this module in any real
-code yet.
+B<WARNING>: The actual semantics in this module are in a very early state of
+implementation. A few things work but most do not. Don't expect to be able to
+use this module in any real code yet.
 
-That said, the only part that isn't actually implemented currently is the part
-that suspends and resumes subroutines while waiting for a future to complete.
-The syntax parsing, as well as semantics for immediate futures, are already
-defined and working now. So it is already very slightly useful for writing
-simple functions that return immediate futures.
+That said, the syntax parsing and semantics for immediate futures are already
+defined and working. So it is already very slightly useful for writing simple
+functions that return immediate futures.
 
 Instead of writing
 
@@ -61,7 +57,7 @@ Instead of writing
 
 you can now simply write
 
- async sub
+ async sub foo
  {
     ...
     return @result;
@@ -72,6 +68,18 @@ be turned into an immediate-failed C<Future> rather than making the call
 itself propagate the exception, which is usually what you wanted when dealing
 with futures.
 
+In addition, code such as the following simple case may work even on
+non-immediate futures:
+
+ async sub bar
+ {
+    my ( $f ) = @_;
+
+    return 1 + await( $f ) + 3;
+ }
+
+For a more complete list of what is still unimplemented, see L</TODO>.
+
 =cut
 
 sub import
@@ -93,6 +101,65 @@ sub import_into
    croak "Unrecognised import symbols @{[ keys %syms ]}" if keys %syms;
 }
 
+=head1 TODO
+
+=over 4
+
+=item *
+
+Save and resume the PAD of the calling function, so that local variables are
+preserved:
+
+ async sub with_pad
+ {
+    my $x = func();
+
+    await $F;
+
+    print "I still have X: $x\n";
+ }
+
+=item *
+
+Suspend and resume over other interesting types of context, such as BLOCK and
+various LOOPs:
+
+ async sub with_loop
+ {
+    while(1) {
+       my $result = await func();
+       return if $result;
+    }
+ }
+
+=item *
+
+Suspend and resume with some consideration for the savestack; i.e. the area
+used to implement C<local> and similar:
+
+ our $VAR;
+
+ async sub with_local
+ {
+    local $VAR = "preserved";
+
+    await $F;
+
+    print "I still have VAR: $VAR\n";
+ }
+
+=item *
+
+Clean up the implementation; check for and fix memory leaks.
+
+=back
+
+=head1 ACKNOWLEDGEMENTS
+
+With thanks to C<Zefram>, C<ilmari> and others from C<irc.perl.org/#p5p> for
+assisting with trickier bits of XS logic. Thanks to C<genio> for project
+management and actually reminding me to write some code.
+
 =head1 AUTHOR
 
 Paul Evans <leonerd@leonerd.org.uk>
